==> cohesity_management_sdk-1.1.1.tar.gz: cohesity_management_sdk-1.1.1/cohesity_management_sdk/models/type_azure_protection_source_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

class TypeAzureProtectionSourceEnum(object):

    """Implementation of the 'Type_AzureProtectionSource' enum.

    Specifies the type of an Azure Protection Source Object such as
    'kStorageContainer', 'kVirtualMachine', 'kVirtualNetwork', etc. Specifies
    the type of an Azure source entity. 'kSubscription' indicates a billing
    unit within Azure account. 'kResourceGroup' indicates a container that
    holds related resources. 'kVirtualMachine' indicates a Virtual Machine in
    Azure environment. 'kStorageAccount' represents a collection of storage
    containers. 'kStorageKey' indicates a key required to access the storage
    account. 'kStorageContainer' represents a storage container within a
    storage account. 'kStorageBlob' represents a storage blog within a storage
    container. 'kStorageResourceGroup' indicates a container that holds
    related storage resources. 'kNetworkSecurityGroup' represents a network
    security group. 'kVirtualNetwork' represents a virtual network.
    'kNetworkResourceGroup' indicates a container that holds related network
    resources. 'kSubnet' represents a subnet within the virtual network.
    'kComputeOptions' indicates the number of CPU cores and memory size
    available for a type of a Virtual Machine.

    Attributes:
        KSUBSCRIPTION: TODO: type description here.
        KRESOURCEGROUP: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KSTORAGEACCOUNT: TODO: type description here.
        KSTORAGEKEY: TODO: type description here.
        KSTORAGECONTAINER: TODO: type description here.
        KSTORAGEBLOB: TODO: type description here.
        KSTORAGERESOURCEGROUP: TODO: type description here.
        KNETWORKSECURITYGROUP: TODO: type description here.
        KVIRTUALNETWORK: TODO: type description here.
        KNETWORKRESOURCEGROUP: TODO: type description here.
        KSUBNET: TODO: type description here.
        KCOMPUTEOPTIONS: TODO: type description here.

    """

    KSUBSCRIPTION = 'kSubscription'

    KRESOURCEGROUP = 'kResourceGroup'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KSTORAGEACCOUNT = 'kStorageAccount'

    KSTORAGEKEY = 'kStorageKey'

    KSTORAGECONTAINER = 'kStorageContainer'

    KSTORAGEBLOB = 'kStorageBlob'

    KSTORAGERESOURCEGROUP = 'kStorageResourceGroup'

    KNETWORKSECURITYGROUP = 'kNetworkSecurityGroup'

    KVIRTUALNETWORK = 'kVirtualNetwork'

    KNETWORKRESOURCEGROUP = 'kNetworkResourceGroup'

    KSUBNET = 'kSubnet'

    KCOMPUTEOPTIONS = 'kComputeOptions'

==> cohesity_management_sdk-1.1.3.tar.gz: cohesity_management_sdk-1.1.3/cohesity_management_sdk/models/type_azure_protection_source_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

class TypeAzureProtectionSourceEnum(object):

    """Implementation of the 'Type_AzureProtectionSource' enum.

    Specifies the type of an Azure Protection Source Object such as
    'kStorageContainer', 'kVirtualMachine', 'kVirtualNetwork', etc.
    Specifies the type of an Azure source entity.
    'kSubscription' indicates a billing unit within Azure account.
    'kResourceGroup' indicates a container that holds related resources.
    'kVirtualMachine' indicates a Virtual Machine in Azure environment.
    'kStorageAccount' represents a collection of storage containers.
    'kStorageKey' indicates a key required to access the storage account.
    'kStorageContainer' represents a storage container within a storage
    account.
    'kStorageBlob' represents a storage blog within a storage container.
    'kStorageResourceGroup' indicates a container that holds related
    storage resources.
    'kNetworkSecurityGroup' represents a network security group.
    'kVirtualNetwork' represents a virtual network.
    'kNetworkResourceGroup' indicates a container that holds related
    network resources.
    'kSubnet' represents a subnet within the virtual network.
    'kComputeOptions' indicates the number of CPU cores and memory size
    available for a type of a Virtual Machine.

    Attributes:
        KSUBSCRIPTION: TODO: type description here.
        KRESOURCEGROUP: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KSTORAGEACCOUNT: TODO: type description here.
        KSTORAGEKEY: TODO: type description here.
        KSTORAGECONTAINER: TODO: type description here.
        KSTORAGEBLOB: TODO: type description here.
        KSTORAGERESOURCEGROUP: TODO: type description here.
        KNETWORKSECURITYGROUP: TODO: type description here.
        KVIRTUALNETWORK: TODO: type description here.
        KNETWORKRESOURCEGROUP: TODO: type description here.
        KSUBNET: TODO: type description here.
        KCOMPUTEOPTIONS: TODO: type description here.

    """

    KSUBSCRIPTION = 'kSubscription'

    KRESOURCEGROUP = 'kResourceGroup'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KSTORAGEACCOUNT = 'kStorageAccount'

    KSTORAGEKEY = 'kStorageKey'

    KSTORAGECONTAINER = 'kStorageContainer'

    KSTORAGEBLOB = 'kStorageBlob'

    KSTORAGERESOURCEGROUP = 'kStorageResourceGroup'

    KNETWORKSECURITYGROUP = 'kNetworkSecurityGroup'

    KVIRTUALNETWORK = 'kVirtualNetwork'

    KNETWORKRESOURCEGROUP = 'kNetworkResourceGroup'

    KSUBNET = 'kSubnet'

    KCOMPUTEOPTIONS = 'kComputeOptions'
